# **Videomass**
[![Image](https://img.shields.io/static/v1?label=python&logo=python&message=3.9%20|%203.10%20|%203.11%20|%203.12&color=blue)](https://www.python.org/downloads/)
[![Image](https://img.shields.io/badge/license-GPLv3-orange)](https://github.com/jeanslack/Videomass/blob/master/LICENSE)
[![Python application](https://github.com/jeanslack/Videomass/actions/workflows/tests.yml/badge.svg)](https://github.com/jeanslack/Videomass/actions/workflows/tests.yml)

It is a FLOSS, powerful, multitasking and cross-platform graphical user interface (GUI) for [FFmpeg](https://www.ffmpeg.org/) and [yt-dlp](https://github.com/yt-dlp/yt-dlp). Designed for advanced and beginner users, it offers a wide range of features and functions, making it a comprehensive software solution.

Videomass is [Free (libre) Software](https://en.wikipedia.org/wiki/Free_software),
written in [Python3](https://www.python.org/) using the
[wxPython Phoenix](https://www.wxpython.org/) toolkit; it works on Linux, MacOs, Windows and FreeBSD.

**[Changelog](https://github.com/jeanslack/Videomass/blob/master/CHANGELOG)**   
**[Features](https://jeanslack.github.io/Videomass/features.html)**   
**[Screenshots](https://jeanslack.github.io/Videomass/screenshots.html)**   

# Resources

* [Official Page](http://jeanslack.github.io/Videomass)
* [Documentations](https://jeanslack.github.io/Videomass/Docs.html)
* [Wiki page](https://github.com/jeanslack/Videomass/wiki)
* [Videomass on PyPi](https://pypi.org/project/videomass/)
* [Development](https://github.com/jeanslack/Videomass)
* [Downloads](https://github.com/jeanslack/Videomass/releases)

# Help translate the program into other languages
DISCLAIMER: By sending a translation you agree to publish your work under the GPL3 license!
- [Localization_Guidelines](https://jeanslack.github.io/Videomass/Pages/Localization_Guidelines)
